fisx: Member List

fisx

fisx::TransmissionTable Member List

This is the complete list of members for fisx::TransmissionTable, including all inherited members.

getComment() const (defined in fisx::TransmissionTable) | fisx::TransmissionTable |
getName() const (defined in fisx::TransmissionTable) | fisx::TransmissionTable |
getTransmission(const double &energy) const | fisx::TransmissionTable |
getTransmission(const std::vector< double > &energy) const | fisx::TransmissionTable |
getTransmissionTable() const | fisx::TransmissionTable |
setComment(const std::string &comment) (defined in fisx::TransmissionTable) | fisx::TransmissionTable |
setName(const std::string &name) (defined in fisx::TransmissionTable) | fisx::TransmissionTable |
setTransmissionTable(const std::map< double, double > &table, const std::string &name="", const std::string &comment="") | fisx::TransmissionTable |
setTransmissionTable(const std::vector< double > &energy, const std::vector< double > &transmission, const std::string &name="", const std::string &comment="") | fisx::TransmissionTable |
TransmissionTable() | fisx::TransmissionTable |
TransmissionTable(const std::string &name, const std::string &comment="") | fisx::TransmissionTable |